package com.spider.quartz.service.impl;

import java.util.List;
import com.spider.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.spider.quartz.mapper.EuUnqualifiedGoodsZhMapper;
import com.spider.quartz.domain.EuUnqualifiedGoodsZh;
import com.spider.quartz.service.IEuUnqualifiedGoodsZhService;

/**
 * 欧盟不合格商品展示-翻译Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-12-05
 */
@Service
public class EuUnqualifiedGoodsZhServiceImpl implements IEuUnqualifiedGoodsZhService 
{
    @Autowired
    private EuUnqualifiedGoodsZhMapper euUnqualifiedGoodsZhMapper;

    /**
     * 查询欧盟不合格商品展示-翻译
     * 
     * @param id 欧盟不合格商品展示-翻译主键
     * @return 欧盟不合格商品展示-翻译
     */
    @Override
    public EuUnqualifiedGoodsZh selectEuUnqualifiedGoodsZhById(Long id)
    {
        return euUnqualifiedGoodsZhMapper.selectEuUnqualifiedGoodsZhById(id);
    }

    /**
     * 查询欧盟不合格商品展示-翻译列表
     * 
     * @param euUnqualifiedGoodsZh 欧盟不合格商品展示-翻译
     * @return 欧盟不合格商品展示-翻译
     */
    @Override
    public List<EuUnqualifiedGoodsZh> selectEuUnqualifiedGoodsZhList(EuUnqualifiedGoodsZh euUnqualifiedGoodsZh)
    {
        return euUnqualifiedGoodsZhMapper.selectEuUnqualifiedGoodsZhList(euUnqualifiedGoodsZh);
    }

    /**
     * 新增欧盟不合格商品展示-翻译
     * 
     * @param euUnqualifiedGoodsZh 欧盟不合格商品展示-翻译
     * @return 结果
     */
    @Override
    public int insertEuUnqualifiedGoodsZh(EuUnqualifiedGoodsZh euUnqualifiedGoodsZh)
    {
        euUnqualifiedGoodsZh.setCreateTime(DateUtils.getNowDate());
        return euUnqualifiedGoodsZhMapper.insertEuUnqualifiedGoodsZh(euUnqualifiedGoodsZh);
    }

    /**
     * 修改欧盟不合格商品展示-翻译
     * 
     * @param euUnqualifiedGoodsZh 欧盟不合格商品展示-翻译
     * @return 结果
     */
    @Override
    public int updateEuUnqualifiedGoodsZh(EuUnqualifiedGoodsZh euUnqualifiedGoodsZh)
    {
        euUnqualifiedGoodsZh.setUpdateTime(DateUtils.getNowDate());
        return euUnqualifiedGoodsZhMapper.updateEuUnqualifiedGoodsZh(euUnqualifiedGoodsZh);
    }

    /**
     * 批量删除欧盟不合格商品展示-翻译
     * 
     * @param ids 需要删除的欧盟不合格商品展示-翻译主键
     * @return 结果
     */
    @Override
    public int deleteEuUnqualifiedGoodsZhByIds(Long[] ids)
    {
        return euUnqualifiedGoodsZhMapper.deleteEuUnqualifiedGoodsZhByIds(ids);
    }

    /**
     * 删除欧盟不合格商品展示-翻译信息
     * 
     * @param id 欧盟不合格商品展示-翻译主键
     * @return 结果
     */
    @Override
    public int deleteEuUnqualifiedGoodsZhById(Long id)
    {
        return euUnqualifiedGoodsZhMapper.deleteEuUnqualifiedGoodsZhById(id);
    }
}
